=================
API documentation
=================

Client
------

.. autoclass:: pylxd.client.Client
   :members:

Certificate
-----------

.. autoclass:: pylxd.certificate.Certificate
   :members:

Container
---------

.. autoclass:: pylxd.container.Container
   :members:

.. autoclass:: pylxd.container.Snapshot
   :members:

Image
-----

.. autoclass:: pylxd.image.Image
   :members:

Network
-------

.. autoclass:: pylxd.network.Network
   :members:

Operation
---------

.. autoclass:: pylxd.operation.Operation
   :members:

Profile
-------

.. autoclass:: pylxd.profile.Profile
   :members:
